import request from '@/utils/request';
import type { ApiResult, PageResult } from '@/api';
import type { Category, CategoryParam } from './model';

/**
 * 分页查询
 */
export async function pageCategory(params: CategoryParam) {
  const res = await request.get<ApiResult<PageResult<Category>>>(
    '/employ/category/page',
    { params }
  );
  if (res.data.code === 0) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 查询列表
 */
export async function listCategory(params?: CategoryParam) {
  const res = await request.get<ApiResult<Category[]>>('/employ/category', {
    params
  });
  if (res.data.code === 0 && res.data.data) {
    return res.data.data;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 添加
 */
export async function addCategory(data: Category) {
  const res = await request.post<ApiResult<unknown>>('/employ/category', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 修改
 */
export async function updateCategory(data: Category) {
  const res = await request.put<ApiResult<unknown>>('/employ/category', data);
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 删除
 */
export async function removeCategory(id?: number) {
  const res = await request.delete<ApiResult<unknown>>(
    '/employ/category/' + id
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}

/**
 * 批量删除
 */
export async function removeCategoryBatch(data: (number | undefined)[]) {
  const res = await request.delete<ApiResult<unknown>>(
    '/employ/category/batch',
    {
      data
    }
  );
  if (res.data.code === 0) {
    return res.data.message;
  }
  return Promise.reject(new Error(res.data.message));
}
